SECRET_KEY = 'not-anymore'

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
    }
}

INSTALLED_APPS = [
    'tests',
]

USE_TZ = False
DEFAULT_AUTO_FIELD = 'django.db.models.AutoField'



from setuptools import find_packages, setup

import picklefield

with open('README.rst') as file_:
    long_description = file_.read()

setup(
    name='django-picklefield',
    version=picklefield.__version__,
    description='Pickled object field for Django',
    long_description=long_description,
    author='Simon Charette',
    author_email='charette.s+django-picklefiel@gmail.com',
    url='http://github.com/gintas/django-picklefield',
    license='MIT',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Framework :: Django :: 3.2',
        'Framework :: Django :: 4.0',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3 :: Only',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Topic :: Software Development :: Libraries :: Application Frameworks',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
    keywords=['django pickle model field'],
    packages=find_packages(exclude=['tests', 'tests.*']),
    python_requires='>=3',
    install_requires=['Django>=3.2'],
    extras_require={
        'tests': ['tox'],
    },
)



from datetime import date

from django.db import models
from picklefield import PickledObjectField

S1 = 'Hello World'
T1 = (1, 2, 3, 4, 5)
L1 = [1, 2, 3, 4, 5]
D1 = {1: 1, 2: 4, 3: 6, 4: 8, 5: 10}
D2 = {1: 2, 2: 4, 3: 6, 4: 8, 5: 10}


class TestCopyDataType(str):
    def __deepcopy__(self, memo):
        raise ValueError('Please dont copy me')


class TestCustomDataType(str):
    pass


class TestingModel(models.Model):
    pickle_field = PickledObjectField()
    compressed_pickle_field = PickledObjectField(compress=True)
    default_pickle_field = PickledObjectField(default=(D1, S1, T1, L1))
    callable_pickle_field = PickledObjectField(default=date.today)
    non_copying_field = PickledObjectField(copy=False, default=TestCopyDataType('boom!'))
    nullable_pickle_field = PickledObjectField(null=True)


class MinimalTestingModel(models.Model):
    pickle_field = PickledObjectField()
